@@ -1,10 +1,10 @@
 import sys
-
-from je_web_runner.utils.test_record.test_record_class import test_record_instance
-from je_web_runner.utils.exception.exceptions import WebRunnerHTMLException
-from je_web_runner.utils.exception.exception_tag import html_generate_no_data_tag
 from threading import Lock
 
+from je_web_runner.utils.exception.exception_tags import html_generate_no_data_tag
+from je_web_runner.utils.exception.exceptions import WebRunnerHTMLException
+from je_web_runner.utils.test_record.test_record_class import test_record_instance
+
 _lock = Lock()
 
 _html_string = \
@@ -113,6 +113,13 @@ _event_table = \
 
 
 def make_html_table(event_str: str, record_data: dict, table_head: str) -> str:
+    """
+    use to add record to html
+    :param event_str: what event trigger
+    :param record_data: what date need to recode
+    :param table_head: table head text
+    :return: whole current str
+    """
     event_str = "".join(
         [
             event_str,
